From 6724a4eb018e6d4fbdc01d1ca3a85604161b4a28 Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Mon, 14 Apr 2008 11:58:09 -0400
Subject: [PATCH] 

---
 server/plugins-available/apache2_plugin.inc.php |    7 +++++--
 1 files changed, 5 insertions(+), 2 deletions(-)

diff --git a/server/plugins-available/apache2_plugin.inc.php b/server/plugins-available/apache2_plugin.inc.php
index 2bc6089..a04ba4c 100644
--- a/server/plugins-available/apache2_plugin.inc.php
+++ b/server/plugins-available/apache2_plugin.inc.php
@@ -219,7 +219,7 @@
 		// Remove the symlink for the site, if site is renamed
 		if($this->action == 'update' && $data["old"]["domain"] != '' && $data["new"]["domain"] != $data["old"]["domain"]) {
 			if(is_dir('/var/log/ispconfig/httpd/'.$data["old"]["domain"])) exec('rm -rf /var/log/ispconfig/httpd/'.$data["old"]["domain"]);
-			if(is_link($data["new"]["document_root"]."/log")) exec("rm -f ".$data["new"]["document_root"]."/log");
+			if(is_link($data["old"]["document_root"]."/log")) exec("rm -f ".$data["old"]["document_root"]."/log");
 		}
 		
 		// Create the symlink for the logfiles
@@ -389,11 +389,14 @@
 			$app->log("Removing symlink: $vhost_symlink => $vhost_file",LOGLEVEL_DEBUG);
 		}
 		
 		// remove old symlink, if domain name of the site has changed
 		if($this->action == 'update' && $data["old"]["domain"] != '' && $data["new"]["domain"] != $data["old"]["domain"]) {
 			$vhost_symlink = escapeshellcmd($web_config["vhost_conf_enabled_dir"].'/'.$data["old"]["domain"].'.vhost');
 			unlink($vhost_symlink);
 			$app->log("Removing symlink: $vhost_symlink => $vhost_file",LOGLEVEL_DEBUG);
+			$vhost_file = escapeshellcmd($web_config["vhost_conf_dir"].'/'.$data["old"]["domain"].'.vhost');
+			unlink($vhost_file);
+			$app->log("Removing File $vhost_file",LOGLEVEL_DEBUG);
 		}
 		
 		// request a httpd reload when all records have been processed
@@ -389,11 +389,14 @@
 		}
 		
-		// remove old symlink, if domain name of the site has changed
+		// remove old symlink and vhost file, if domain name of the site has changed
 		if($this->action == 'update' && $data["old"]["domain"] != '' && $data["new"]["domain"] != $data["old"]["domain"]) {
 			$vhost_symlink = escapeshellcmd($web_config["vhost_conf_enabled_dir"].'/'.$data["old"]["domain"].'.vhost');

--
Gitblit v1.9.1